@@ -55,11 +55,30 @@ def did_delete_all(dids=None):
             db.session.execute("delete from resource_prefix where code::varchar in ( select did from did_billing_rel);")
             db.session.execute("delete from did_billing_rel;")
         else:
-            dids = ','.join(["'" + did + "'" for did in dids.split(',')])
-            db.session.execute("update did_client_log set released_on = now() where released_on is null and did in ({});".format(dids))
-            db.session.execute("delete from product_items where product_id = 1 and digits::varchar in ({});".format(dids))
-            db.session.execute("delete from resource_prefix where code::varchar in ({});".format(dids))
-            db.session.execute("delete from did_billing_rel where did in ({});".format(dids))
+            did_list = [did.strip() for did in dids.split(',')]
+            # Validate each DID matches phone number pattern to prevent SQL injection
+            for did in did_list:
+                if not re.match(PHONE_REGEXP, did):
+                    log.debug(f"SQL_INJECTION_ATTEMPT: did_delete_all invalid DID format: {repr(did)}")
+                    log.error('did_delete_all invalid DID format: {}'.format(did))
+                    return
+            did_tuple = tuple(did_list)
+            db.session.execute(
+                text_("update did_client_log set released_on = now() where released_on is null and did in :dids"),
+                {'dids': did_tuple}
+            )
+            db.session.execute(
+                text_("delete from product_items where product_id = 1 and digits::varchar in :dids"),
+                {'dids': did_tuple}
+            )
+            db.session.execute(
+                text_("delete from resource_prefix where code::varchar in :dids"),
+                {'dids': did_tuple}
+            )
+            db.session.execute(
+                text_("delete from did_billing_rel where did in :dids"),
+                {'dids': did_tuple}
+            )
     except Exception as e:
         log.error('did_delete_all did not deleted {}'.format(e))
         try:
