@@ -1410,7 +1410,8 @@ def do_block_number_import_preprocess(obj_id, egress_client_id, egress_trunk_id,
                     row = {fmap[k]: v for k, v in read_row.items() if fmap[k] != 'ignore'}
                     for field in ('egress_trunk_id', 'ingress_trunk_id'):
                         if field not in row:
-                            row[field] = str(eval(field)) if eval(field) else ''
+                            value = locals().get(field)
+                            row[field] = str(value) if value is not None else ''
 
                     if not time_profile_name:
                         row['time_profile_id'] = ''
