@@ -394,6 +394,9 @@ class ShakenStiSpConfCreate(DnlCreate):
     def on_post(self, req, resp, **kwargs):
         default_key = req.data.get("default_key") == "true"
         session = model.get_db().session
+        if not default_key and not session.query(model.ShakenStiSpConf).first():
+            log.debug('No records in db, set default_key=true')
+            default_key = True
         try:
             priv_key = req.data.get('priv_key')
             if not ShakenStiSpConfResource.validate_priv_key(priv_key):
@@ -487,6 +490,17 @@ class ShakenStiSpConfResource(DnlResource):
                     responses.ValidationErrorResponse(data={'x5u': 'bad value'})
                 )
                 return False
+
+            total = session.query(model.ShakenStiSpConf).count()
+            if total == 1 and default_key is False:
+                self.set_response(
+                    resp,
+                    responses.ValidationErrorResponse(
+                        data={'default_key': 'cannot unset default_key; only one record exists'}
+                    )
+                )
+                return False
+
             if default_key:
                 sql = text("""
                     WITH reset AS (
@@ -535,6 +549,39 @@ class ShakenStiSpConfResource(DnlResource):
             self.set_response(resp, OperationErrorResponse(e))
             return False
 
+
+    def on_delete(self, req, resp, **kwargs):
+        result = super(ShakenStiSpConfResource, self).on_delete(req, resp, **kwargs)
+
+        if resp.status != 200 and resp.status != '200 OK':
+            return result
+
+        session = model.get_db().session
+
+        try:
+            has_default = (
+                session.query(model.ShakenStiSpConf)
+                .filter(model.ShakenStiSpConf.default_key == True)
+                .first()
+            )
+
+            if has_default is None:
+                last_row = (
+                    session.query(model.ShakenStiSpConf)
+                    .order_by(model.ShakenStiSpConf.id.desc())
+                    .first()
+                )
+
+                if last_row:
+                    last_row.default_key = True
+                    session.commit()
+
+        except Exception as e:
+            session.rollback()
+            log.error(f"Failed to restore default_key: {e}")
+
+        return result
+
     @staticmethod
     def validate_priv_key(priv_key):
         try:
